Function that generates a table of active days for all periods. The unique list of fishing units are inherited from available tables (active_vessels, effort, landings). In the same way, the list of minor strata values will be inherited based on the minor_strata columns available in data.
Usage
generate_active_days(
effort,
effort_source = c("fisher_interview", "boat_counting", "household_interview"),
landings,
active_vessels = NULL,
minor_strata = NULL
)