Generates a tibble of active days.
Source:R/artfish_active_days.R
generate_active_days_by_period.RdFunction that generates a table of active days by year/month. The unique list of fishing units are inherited from available tables (active_vessels, effort, landings). In the same way, the list of minor strata values will be inherited based on the minor_strata columns available in data.
Usage
generate_active_days_by_period(
year,
month,
active_vessels,
effort,
effort_source = c("fisher_interview", "boat_counting"),
landings,
minor_strata = NULL
)